#
# spec file for package python-falcon
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-falcon
Version:        0.2
Release:        4.3
Summary:        A supersonic micro-framework for building cloud APIs
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://falconframework.org
Source:         https://pypi.python.org/packages/source/f/falcon/falcon-%{version}.tar.gz
BuildRequires:  python-Cython
BuildRequires:  python-devel
# Test requirements:
BuildRequires:  python-ddt
BuildRequires:  python-nose
BuildRequires:  python-yaml
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-ordereddict
%endif
BuildRequires:  python-requests
BuildRequires:  python-six
BuildRequires:  python-testtools
Requires:       python-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
Requires:       python-ordereddict
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
Falcon is a high-performance Python framework for building cloud
APIs. It encourages the REST architectural style, and tries to do
as little as possible while remaining highly effective.

%prep
%setup -q -n falcon-%{version}
# remove unwanted shebang
sed -i '1 { /^#!/ d }' falcon/bench/bench.py

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py -q test

%files
%defattr(-,root,root,-)
%doc README.rst
%{_bindir}/falcon-bench
%{python_sitearch}/*

%changelog
* Mon May  4 2015 benoit.monin@gmx.fr
- update to version 0.2:
  * Since 0.1 we've added proper RTD docs to make it easier for
    everyone to get started with the framework. Over time we will
    continue adding content, and we would love your help!
  * Falcon now supports "wsgi.filewrapper". You can assign any
    file-like object to resp.stream and Falcon will use
    "wsgi.filewrapper" to more efficiently pipe the data to the
    WSGI server.
  * Support was added for automatically parsing requests containing
    "application/x-www-form-urlencoded" content. Form fields are
    now folded into req.params.
  * Custom Request and Response classes are now supported. You can
    specify custom types when instantiating falcon.API.
  * A new middleware feature was added to the framework. Middleware
    deprecates global hooks, and we encourage everyone to migrate
    as soon as possible.
  * A general-purpose dict attribute was added to Request.
    Middleware, hooks, and responders can now use req.context to
    share contextual information about the current request.
  * A new method, append_header, was added to falcon.API to allow
    setting multiple values for the same header using comma
    separation.
  * A new "resource" attribute was added to hooks. Old hooks that
    do not accept this new attribute are shimmed so that they will
    continue to function.
  * Error response bodies now support XML in addition to JSON. In
    addition, the HTTPError serialization code was refactored to
    make it easier to implement a custom error serializer.
  * A new method, "set_error_serializer" was added to falcon.API.
    You can use this method to override Falcon's default HTTPError
    serializer if you need to support custom media types.
  * Falcon's testing base class, testing.TestBase was improved to
    facilitate Py3k testing.
  * An "add_link" method was added to the Response class. Apps can
    use this method to add one or more Link header values to a
    response.
  * Added two new properties, req.host and req.subdomain, to make
    it easier to get at the hostname info in the request.
  * Allow a wider variety of characters to be used in query string
    params.
  * Internal APIs have been refactored to allow overriding the
    default routing mechanism. Further modularization is planned
    for the next release (0.3).
  * Changed req.get_param so that it behaves the same whether a
    list was specified in the query string using the HTML form
    style (in which each element is listed in a separate 'key=val'
    field) or in the more compact API style (in which each element
    is comma-separated and assigned to a single param instance, as
    in 'key=val1,val2,val3')
  * Added a convenience method, set_stream(...), to the Response
    class for setting the stream and its length at the same time,
    which should help people not forget to set both (and save a few
    keystrokes along the way).
  * Added several new error classes, including
    HTTPRequestEntityTooLarge, HTTPInvalidParam, HTTPMissingParam,
    HTTPInvalidHeader and HTTPMissingHeader.
  * Python 3.4 is now fully supported.
  * Various minor performance improvements
  * The deprecated util.misc.percent_escape and
    util.misc.percent_unescape functions were removed. Please use
    the functions in the util.uri module instead.
  * The deprecated function, API.set_default_route, was removed.
    Please use sinks instead.
  * HTTPRangeNotSatisfiable no longer accepts a media_type
    parameter.
  * When using the comma-delimited list convention,
    req.get_param_as_list(...) will no longer insert placeholders,
    using the None type, for empty elements.
  * Ensure 100%% test coverage and fix any bugs identified in the
    process.
  * Fix not recognizing the "bytes=" prefix in Range headers.
  * Make HTTPNotFound and HTTPMethodNotAllowed fully compliant,
    according to RFC 7231.
  * Fixed the default on_options responder causing a Cython type
    error.
  * URI template strings can now be of type unicode under Python 2.
  * When SCRIPT_NAME is not present in the WSGI environ, return an
    empty string for the req.app property.
  * Global "after" hooks will now be executed even when a responder
    raises an error.
  * Fixed several minor issues regarding testing.create_environ(...)
  * Work around a wsgiref quirk, where if no content-length header
    is submitted by the client, wsgiref will set the value of that
    header to an empty string in the WSGI environ.
  * Resolved an issue causing several source files to not be
    Cythonized.
  * Docstrings have been edited for clarity and correctness.
- additional changes from version 0.1.10:
  * SCRIPT_NAME may not always be present in the WSGI environment,
    so treat it as an empty string if not present.
- additional changes from version 0.1.9:
  * Addressed style issues reported by the latest pyflakes version
  * Fixed body not being decoded from UTF-8 in HTTPError tests
  * Remove unnecessary ordereddict requirement on Python 2.6
- additional changes from version 0.1.8:
  * srmock.headers have been normalized such that header names are
    always lowercase. This was done to make tests that rely on
    srmock less fragile.
  * Falcon now sends response headers as all lower-case ala node.js.
  * The 'scheme' argument to HTTPUnauthorized can no longer be
    passed positionally; it must be a named argument.
  * You can no longer overload a single resource class to respond
    to multiple routes that differ by URI template params.
  * srmock.headers_dict is now implemented using a case-insensitive
    dict
  * Per RFC 3986, Falcon now decodes escaped characters in the
    query string, plus convert '+' -> ' '. Also, Falcon now decodes
    multi-byte UTF-8 sequences after they have been unescaped.
  * Custom error handlers can be registered via a new
    API.add_error_handler method.
  * Support for "request sinks" was added to falcon.API.
  * uri module added to falcon.util which includes utilities for
    encoding and decoding URIs, as well as parsing a query string
    into a dict.
  * Subsequent calls to req.uri are now faster since the property
    now clones a cached dict instead of building a new one from
    scratch each time.
  * falcon.util now includes a case-insensitive dict borrowed from
    the Requests library.
  * Misc. performance optimizations to offset the impact of
    supporting case-sensitive headers and rigorous URI
    encoding/decoding.
  * Py33 performance improvements
- add python-ddt and python-yaml as BuildRequires for the tests
- remove unwanted shebang of bench.py
- add -fno-strict-aliasing to CFLAGS to avoid compiler warnings
- pass -q to test to avoid spamming the build log
- remove AUTHORS CHANGES.md LICENSE: no provided anymore
- remove README.md: its content is identical to README.rst
* Mon Sep 30 2013 speilicke@suse.com
- Fix description
* Tue Sep 17 2013 dmueller@suse.com
- update to 0.1.7:
  * req.get_params_as_list now inserts None as a placeholder for missing
  elements, and returns None all by itself if the param is present in the
  query string, but has an empty string as its value. (kgriffs)
* Mon Sep  9 2013 speilicke@suse.com
- Add python-ordereddict test build requirement for SLE_11_SP3
* Mon Sep  9 2013 speilicke@suse.com
- Initial version
